@@ -6,4 +6,4 @@ from .file_handlers import register_filehandler
 
 # These imports register default file handlers
 from .csv_handler import CsvHandler
-from .netcdf_handler import NetCdfHandler
+from .netcdf_handler import NetCdfHandler, SplitNetCdfHandler
